@@ -17,6 +17,7 @@
 
 from ai.h2o.sparkling.ml.params.H2OMOJOModelParams import H2OTreeBasedUnsupervisedMOJOModelParams
 from pyspark.ml.util import _jvm
+from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
@@ -31,6 +32,17 @@ class H2OIsolationForestMOJOModel(H2OTreeBasedUnsupervisedMOJOModelParams):
         javaModel = _jvm().ai.h2o.sparkling.ml.models.H2OIsolationForestMOJOModel.createFromMojo(pathToMojo, settings.toJavaObject())
         return H2OIsolationForestMOJOModel(javaModel)
 
+
+    def getCrossValidationModels(self):
+        cvModels = self._java_obj.getCrossValidationModelsAsArray()
+        if cvModels is None:
+            return None
+        elif isinstance(cvModels, JavaObject):
+            return [H2OIsolationForestMOJOModel(v) for v in cvModels]
+        else:
+            raise TypeError("Invalid type.")
+
+
     def getSampleSize(self):
         value = self._java_obj.getSampleSize()
         return value
@@ -129,3 +141,8 @@ class H2OIsolationForestMOJOModel(H2OTreeBasedUnsupervisedMOJOModelParams):
     def getExportCheckpointsDir(self):
         value = self._java_obj.getExportCheckpointsDir()
         return value
+
+
+    def getVariableSplits(self):
+        value = self._java_obj.getVariableSplits()
+        return H2OTypeConverters.scalaToPythonDataFrame(value)
